==> forestry_1.9.4-5.0.0.102-sources.jar: forestry/factory/recipes/jei/rainmaker/RainmakerRecipeWrapper.java <==
package forestry.factory.recipes.jei.rainmaker;

import javax.annotation.Nonnull;
import java.awt.Color;
import java.util.Collections;
import java.util.List;

import net.minecraft.client.Minecraft;
import net.minecraft.item.ItemStack;

import forestry.api.fuels.RainSubstrate;
import forestry.core.utils.Translator;

import mezz.jei.api.recipe.BlankRecipeWrapper;

public class RainmakerRecipeWrapper extends BlankRecipeWrapper {
	@Nonnull
	private final RainSubstrate substrate;

	public RainmakerRecipeWrapper(@Nonnull RainSubstrate substrate) {
		this.substrate = substrate;
	}

	@Nonnull
	@Override
	public List<List<ItemStack>> getInputs() {
		return Collections.singletonList(Collections.singletonList(substrate.getItem()));
	}

	@Override
	public void drawInfo(@Nonnull Minecraft minecraft, int recipeWidth, int recipeHeight, int mouseX, int mouseY) {
		super.drawInfo(minecraft, recipeWidth, recipeHeight, mouseX, mouseY);

		minecraft.field_71466_p.func_78276_b(getEffectString(), 24, 0, Color.darkGray.getRGB());
		String speed = Translator.translateToLocalFormatted("for.jei.rainmaker.speed", substrate.getSpeed());
		minecraft.field_71466_p.func_78276_b(speed, 24, 10, Color.gray.getRGB());
		if (!substrate.isReverse()) {
			String duration = Translator.translateToLocalFormatted("for.jei.rainmaker.duration", substrate.getDuration());
			minecraft.field_71466_p.func_78276_b(duration, 24, 20, Color.gray.getRGB());
		}
	}

	private String getEffectString() {
		if (substrate.isReverse()) {
			return Translator.translateToLocal("for.jei.rainmaker.stops.rain");
		} else {
			return Translator.translateToLocal("for.jei.rainmaker.causes.rain");
		}
	}
}

==> forestry_1.9-5.0.0.61-sources.jar: forestry/factory/recipes/jei/rainmaker/RainmakerRecipeWrapper.java <==
package forestry.factory.recipes.jei.rainmaker;

import javax.annotation.Nonnull;
import java.awt.Color;
import java.util.Collections;
import java.util.List;

import net.minecraft.client.Minecraft;
import net.minecraft.item.ItemStack;

import forestry.api.fuels.RainSubstrate;
import forestry.core.utils.Translator;

import mezz.jei.api.recipe.BlankRecipeWrapper;

public class RainmakerRecipeWrapper extends BlankRecipeWrapper {
	@Nonnull
	private final RainSubstrate substrate;

	public RainmakerRecipeWrapper(@Nonnull RainSubstrate substrate) {
		this.substrate = substrate;
	}

	@Nonnull
	@Override
	public List<List<ItemStack>> getInputs() {
		return Collections.singletonList(Collections.singletonList(substrate.getItem()));
	}

	@Override
	public void drawInfo(@Nonnull Minecraft minecraft, int recipeWidth, int recipeHeight, int mouseX, int mouseY) {
		super.drawInfo(minecraft, recipeWidth, recipeHeight, mouseX, mouseY);

		minecraft.fontRendererObj.drawString(getEffectString(), 24, 0, Color.darkGray.getRGB());
		String speed = Translator.translateToLocalFormatted("for.jei.rainmaker.speed", substrate.getSpeed());
		minecraft.fontRendererObj.drawString(speed, 24, 10, Color.gray.getRGB());
		if (!substrate.isReverse()) {
			String duration = Translator.translateToLocalFormatted("for.jei.rainmaker.duration", substrate.getDuration());
			minecraft.fontRendererObj.drawString(duration, 24, 20, Color.gray.getRGB());
		}
	}

	private String getEffectString() {
		if (substrate.isReverse()) {
			return Translator.translateToLocal("for.jei.rainmaker.stops.rain");
		} else {
			return Translator.translateToLocal("for.jei.rainmaker.causes.rain");
		}
	}
}
